Module blaxel.core.sandbox.client.models.process_response
=========================================================

Classes
-------

`ProcessResponse(command: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>, completed_at: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>, exit_code: blaxel.core.sandbox.client.types.Unset | int = <blaxel.core.sandbox.client.types.Unset object>, name: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>, pid: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>, started_at: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>, status: blaxel.core.sandbox.client.types.Unset | blaxel.core.sandbox.client.models.process_response_status.ProcessResponseStatus = <blaxel.core.sandbox.client.types.Unset object>, working_dir: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>)`
:   Attributes:
        command (Union[Unset, str]):  Example: ls -la.
        completed_at (Union[Unset, str]):  Example: Wed, 01 Jan 2023 12:01:00 GMT.
        exit_code (Union[Unset, int]):
        name (Union[Unset, str]):  Example: my-process.
        pid (Union[Unset, str]):  Example: 1234.
        started_at (Union[Unset, str]):  Example: Wed, 01 Jan 2023 12:00:00 GMT.
        status (Union[Unset, ProcessResponseStatus]):  Example: running.
        working_dir (Union[Unset, str]):  Example: /home/user.
    
    Method generated by attrs for class ProcessResponse.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `command: blaxel.core.sandbox.client.types.Unset | str`
    :

    `completed_at: blaxel.core.sandbox.client.types.Unset | str`
    :

    `exit_code: blaxel.core.sandbox.client.types.Unset | int`
    :

    `name: blaxel.core.sandbox.client.types.Unset | str`
    :

    `pid: blaxel.core.sandbox.client.types.Unset | str`
    :

    `started_at: blaxel.core.sandbox.client.types.Unset | str`
    :

    `status: blaxel.core.sandbox.client.types.Unset | blaxel.core.sandbox.client.models.process_response_status.ProcessResponseStatus`
    :

    `working_dir: blaxel.core.sandbox.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :